@@ -16,11 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: apputil.c,v 1.48 2007/10/25 05:48:55 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 #include <sys/signal.h>
 #include <sys/stat.h>
 #include <sys/types.h>
