@@ -16,11 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: lchfn.c,v 1.25 2006/03/06 03:02:52 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 #include <sys/stat.h>
 #include <libintl.h>
 #include <locale.h>
