@@ -16,11 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: lgroupmod.c,v 1.35 2005/10/09 05:15:47 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 #include <errno.h>
 #include <inttypes.h>
 #include <stdio.h>
