@@ -16,11 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: lpasswd.c,v 1.19 2005/12/02 17:32:24 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 #include <libintl.h>
 #include <limits.h>
 #include <locale.h>
