@@ -15,11 +15,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: config.c,v 1.23 2008/01/08 12:10:22 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "../config.h"
-#endif
+#include <config.h>
 #include <assert.h>
 #include <sys/stat.h>
 #include <ctype.h>
