@@ -15,11 +15,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: scache.c,v 1.8 2006/01/31 00:22:40 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "../config.h"
-#endif
+#include <config.h>
 #include <string.h>
 #include "user_private.h"
 #include "internal.h"
