@@ -15,11 +15,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: user.c,v 1.85 2007/06/15 11:56:36 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "../config.h"
-#endif
+#include <config.h>
 #include <sys/types.h>
 #include <errno.h>
 #include <grp.h>
