@@ -16,11 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: util.c,v 1.20 2008/01/09 10:13:46 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "../config.h"
-#endif
+#include <config.h>
 #include <sys/mman.h>
 #include <sys/stat.h>
 #include <sys/time.h>
