@@ -16,11 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: krb5.c,v 1.29 2005/11/11 23:29:40 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <errno.h>
