@@ -16,11 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: sasldb.c,v 1.14 2006/02/21 16:17:32 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 #include <sasl/sasl.h>
 #include <stdio.h>
 #include <stdlib.h>
