@@ -15,12 +15,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: admin.c,v 1.47 2007/10/11 03:18:34 mitr Exp $"
-
 #include <Python.h>
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 #include <grp.h>
 #include <pwd.h>
 #include <stdlib.h>
