@@ -15,12 +15,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: ent.c,v 1.32 2007/01/06 20:40:17 katzj Exp $"
-
 #include <Python.h>
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 #include <pwd.h>
 #include <grp.h>
 #include <stdlib.h>
