@@ -16,11 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: homedir.c,v 1.8 2006/05/01 04:51:21 mitr Exp $"
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 #include <libintl.h>
 #include <locale.h>
 #include <stdio.h>
