@@ -1,9 +1,13 @@
 import crypt
 import libuser
+import os
+import os.path
 import unittest
 
 LARGE_ID = 2147483648
 
+workdir = os.environ['workdir']
+
 # Test case order matches the order of function pointers in struct lu_module
 class Tests(unittest.TestCase):
     def setUp(self):
@@ -44,6 +48,27 @@ class Tests(unittest.TestCase):
         self.assertEqual(e[libuser.SHADOWEXPIRE], [-1])
         self.assertEqual(e[libuser.SHADOWFLAG], [-1])
 
+    def testUserLookupName3(self):
+        # Handling of values that appear to be numbers
+        e = self.a.lookupUserByName('077')
+        self.assert_(e)
+        self.assertEqual(e[libuser.USERNAME], ['077'])
+        self.assertEqual(e[libuser.USERPASSWORD], ['077'])
+        self.assertEqual(e[libuser.UIDNUMBER], [230])
+        self.assertEqual(e[libuser.GIDNUMBER], [231])
+        self.assertEqual(e[libuser.GECOS], ['077'])
+        self.assertEqual(e[libuser.HOMEDIRECTORY], ['077'])
+        self.assertEqual(e[libuser.LOGINSHELL], ['077'])
+        self.assertEqual(e[libuser.SHADOWNAME], ['077'])
+        self.assertEqual(e[libuser.SHADOWPASSWORD], ['077'])
+        self.assertEqual(e[libuser.SHADOWLASTCHANGE], [77])
+        self.assertEqual(e[libuser.SHADOWMIN], [77])
+        self.assertEqual(e[libuser.SHADOWMAX], [77])
+        self.assertEqual(e[libuser.SHADOWWARNING], [77])
+        self.assertEqual(e[libuser.SHADOWINACTIVE], [77])
+        self.assertEqual(e[libuser.SHADOWEXPIRE], [77])
+        self.assertEqual(e[libuser.SHADOWFLAG], [77])
+
     def testUserLookupId(self):
         e = self.a.initUser('user3_1')
         self.a.addUser(e, False, False)
@@ -59,10 +84,12 @@ class Tests(unittest.TestCase):
         e = self.a.lookupUserById(LARGE_ID + 310)
         self.assertEqual(e, None)
 
-    # testUserDefault
-    # There is little to test, in addition most is configurable
+    def testUserDefault(self):
+        # Test the default/LU_USERNAME = %n preserves usernames that appear to
+        # be numbers
+        e = self.a.initUser('077')
+        self.assertEqual(e[libuser.USERNAME], ['077'])
 
-    # testUserAddPrep
     # Setting of USERPASSWORD to "x" tested below
     def testUserAddPrep(self):
         # Nothing to do with the "files" module: tests of lu_name_allowed()
@@ -172,6 +199,19 @@ class Tests(unittest.TestCase):
         self.assertEqual(e[libuser.UIDNUMBER], [LARGE_ID + 630])
         self.assertEqual(e[libuser.GIDNUMBER], [LARGE_ID + 631])
 
+    def testUserAdd4(self):
+        # Error handling when creating the home directory
+        e = self.a.initUser('user6_4')
+        e[libuser.HOMEDIRECTORY] = os.path.join(workdir, 'this_doesnt_exist',
+                                                'user6_4')
+        self.assertRaises(RuntimeError, self.a.addUser, e, mkmailspool = False)
+
+    def testUserAdd5(self):
+        # Non-absolute home directories
+        e = self.a.initUser('user6_5')
+        e[libuser.HOMEDIRECTORY] = 'this_is_a_relative_path'
+        self.assertRaises(RuntimeError, self.a.addUser, e, mkmailspool = False)
+
     def testUserMod1(self):
         # A minimal case
         e = self.a.initUser('user7_1')
@@ -405,30 +445,72 @@ class Tests(unittest.TestCase):
         self.assertEqual(e[libuser.SHADOWPASSWORD], ['01aK1FxKE9YVU'])
         self.assertEqual(self.a.userIsLocked(e), 0)
 
-    def testUserSetpass(self):
+    def testUserSetpass1(self):
         e = self.a.initUser('user12_1')
         e[libuser.SHADOWPASSWORD] = '02oawyZdjhhpg'
+        e[libuser.SHADOWLASTCHANGE] = 100
         self.a.addUser(e, False, False)
         del e
         e = self.a.lookupUserByName('user12_1')
         self.assertEqual(e[libuser.USERPASSWORD], ['x'])
         self.assertEqual(e[libuser.SHADOWPASSWORD], ['02oawyZdjhhpg'])
+        self.assertEqual(e[libuser.SHADOWLASTCHANGE], [100])
+        self.a.setpassUser(e, 'password', False)
+        del e
+        e = self.a.lookupUserByName('user12_1')
+        self.assertEqual(e[libuser.USERPASSWORD], ['x'])
+        crypted = crypt.crypt('password', e[libuser.SHADOWPASSWORD][0])
+        self.assertEqual(e[libuser.SHADOWPASSWORD], [crypted])
+        self.assert_(e[libuser.SHADOWLASTCHANGE][0] > 10000)
+
+    def testUserSetpass2(self):
+        # Forcing the non-shadow password to 'x'
+        e = self.a.initUser('user12_2')
+        e[libuser.USERPASSWORD] = '*'
+        e[libuser.SHADOWPASSWORD] = '08lnuxCM.c36E'
+        self.a.addUser(e, False, False)
+        del e
+        # shadow module's addUser forces USERPASSWORD to 'x'
+        e = self.a.lookupUserByName('user12_2')
+        self.assertEqual(e[libuser.USERPASSWORD], ['x'])
+        self.assertEqual(e[libuser.SHADOWPASSWORD], ['08lnuxCM.c36E'])
+        e[libuser.USERPASSWORD] = '*'
+        self.a.modifyUser(e, False)
+        del e
+        e = self.a.lookupUserByName('user12_2')
+        self.assertEqual(e[libuser.USERPASSWORD], ['*'])
+        self.assertEqual(e[libuser.SHADOWPASSWORD], ['08lnuxCM.c36E'])
         self.a.setpassUser(e, 'password', False)
         self.assertEqual(e[libuser.USERPASSWORD], ['x'])
-        crypted = crypt.crypt('password', e[libuser.SHADOWPASSWORD][0][:11])
+        crypted = crypt.crypt('password', e[libuser.SHADOWPASSWORD][0])
         self.assertEqual(e[libuser.SHADOWPASSWORD], [crypted])
 
+    def testUserSetpass3(self):
+        # Overriding an invalid encrypted password
+        e = self.a.lookupUserByName('user12_3')
+        self.assertEqual(e[libuser.USERPASSWORD], ['*'])
+        self.assertRaises(KeyError, lambda: e[libuser.SHADOWPASSWORD])
+        self.a.setpassUser(e, 'password', False)
+        crypted = crypt.crypt('password', e[libuser.USERPASSWORD][0])
+        self.assertEqual(e[libuser.USERPASSWORD], [crypted])
+        self.assertRaises(KeyError, lambda: e[libuser.SHADOWPASSWORD])
+
     def testUserRemovepass(self):
         e = self.a.initUser('user13_1')
         e[libuser.SHADOWPASSWORD] = '03dgZm5nZvqOc'
+        e[libuser.SHADOWLASTCHANGE] = 100
         self.a.addUser(e, False, False)
         del e
         e = self.a.lookupUserByName('user13_1')
         self.assertEqual(e[libuser.USERPASSWORD], ['x'])
         self.assertEqual(e[libuser.SHADOWPASSWORD], ['03dgZm5nZvqOc'])
+        self.assertEqual(e[libuser.SHADOWLASTCHANGE], [100])
         self.a.removepassUser(e)
+        del e
+        e = self.a.lookupUserByName('user13_1')
         self.assertEqual(e[libuser.USERPASSWORD], ['x'])
         self.assertEqual(e[libuser.SHADOWPASSWORD], [''])
+        self.assert_(e[libuser.SHADOWLASTCHANGE][0] > 10000)
 
     def testUsersEnumerate1(self):
         e = self.a.initUser('user14_1')
@@ -526,9 +608,20 @@ class Tests(unittest.TestCase):
         self.assertEqual(e[libuser.GROUPNAME], ['empty_group'])
         self.assertEqual(e[libuser.GROUPPASSWORD], [''])
         self.assertEqual(e[libuser.GIDNUMBER], [44])
-        self.assertRaises(KeyError, lambda x: x[libuser.MEMBERNAME], e)
+        self.assertRaises(KeyError, lambda: e[libuser.MEMBERNAME])
         self.assertEqual(e[libuser.SHADOWPASSWORD], [''])
-        self.assertRaises(KeyError, lambda x: x[libuser.ADMINISTRATORNAME], e)
+        self.assertRaises(KeyError, lambda: e[libuser.ADMINISTRATORNAME])
+
+    def testGroupLookupName3(self):
+        # Handling of values that appear to be numbers
+        e = self.a.lookupGroupByName('077')
+        self.assert_(e)
+        self.assertEqual(e[libuser.GROUPNAME], ['077'])
+        self.assertEqual(e[libuser.GROUPPASSWORD], ['077'])
+        self.assertEqual(e[libuser.GIDNUMBER], [1730])
+        self.assertEqual(e[libuser.MEMBERNAME], ['077'])
+        self.assertEqual(e[libuser.SHADOWPASSWORD], ['077'])
+        self.assertEqual(e[libuser.ADMINISTRATORNAME], ['077'])
 
     def testGroupLookupId(self):
         e = self.a.initGroup('group18_1')
@@ -545,8 +638,11 @@ class Tests(unittest.TestCase):
         e = self.a.lookupGroupById(LARGE_ID + 1810)
         self.assertEqual(e, None)
 
-    # testGroupDefault
-    # There is little to test, in addition most is configurable
+    def testGroupDefault(self):
+        # Test the default/LU_GROUPNAME = %n preserves groupnames that appear
+        # to be numbers
+        e = self.a.initGroup('077')
+        self.assertEqual(e[libuser.GROUPNAME], ['077'])
 
     # testGroupAddPrep
     # Setting of GROUPPASSWORD to "x" tested below
@@ -783,8 +879,8 @@ class Tests(unittest.TestCase):
         self.assertEqual(e[libuser.GROUPPASSWORD], ['x'])
         self.assertEqual(e[libuser.SHADOWPASSWORD], ['05/lfLEyErrp2'])
         self.assertEqual(self.a.groupIsLocked(e), 0)
-        
-    def testGroupSetpass(self):
+
+    def testGroupSetpass1(self):
         e = self.a.initGroup('group27_1')
         e[libuser.SHADOWPASSWORD] = '06aZrb3pzuu/6'
         self.a.addGroup(e)
@@ -794,9 +890,41 @@ class Tests(unittest.TestCase):
         self.assertEqual(e[libuser.SHADOWPASSWORD], ['06aZrb3pzuu/6'])
         self.a.setpassGroup(e, 'password', False)
         self.assertEqual(e[libuser.GROUPPASSWORD], ['x'])
-        crypted = crypt.crypt('password', e[libuser.SHADOWPASSWORD][0][:11])
+        crypted = crypt.crypt('password', e[libuser.SHADOWPASSWORD][0])
         self.assertEqual(e[libuser.SHADOWPASSWORD], [crypted])
 
+    def testGroupSetpass2(self):
+        # Forcing the non-shadow password to 'x'
+        e = self.a.initGroup('group27_2')
+        e[libuser.GROUPPASSWORD] = '*'
+        e[libuser.SHADOWPASSWORD] = '07ZZy2Pihe/gg'
+        self.a.addGroup(e)
+        del e
+        # shadow module's addGroup forces GROUPPASSWORD to 'x'
+        e = self.a.lookupGroupByName('group27_2')
+        self.assertEqual(e[libuser.GROUPPASSWORD], ['x'])
+        self.assertEqual(e[libuser.SHADOWPASSWORD], ['07ZZy2Pihe/gg'])
+        e[libuser.GROUPPASSWORD] = '*'
+        self.a.modifyGroup(e)
+        del e
+        e = self.a.lookupGroupByName('group27_2')
+        self.assertEqual(e[libuser.GROUPPASSWORD], ['*'])
+        self.assertEqual(e[libuser.SHADOWPASSWORD], ['07ZZy2Pihe/gg'])
+        self.a.setpassGroup(e, 'password', False)
+        self.assertEqual(e[libuser.GROUPPASSWORD], ['x'])
+        crypted = crypt.crypt('password', e[libuser.SHADOWPASSWORD][0])
+        self.assertEqual(e[libuser.SHADOWPASSWORD], [crypted])
+
+    def testGroupSetpass3(self):
+        # Overriding an invalid encrypted password
+        e = self.a.lookupGroupByName('group27_3')
+        self.assertEqual(e[libuser.GROUPPASSWORD], ['*'])
+        self.assertRaises(KeyError, lambda: e[libuser.SHADOWPASSWORD])
+        self.a.setpassGroup(e, 'password', False)
+        crypted = crypt.crypt('password', e[libuser.GROUPPASSWORD][0])
+        self.assertEqual(e[libuser.GROUPPASSWORD], [crypted])
+        self.assertRaises(KeyError, lambda: e[libuser.SHADOWPASSWORD])
+
     def testGroupRemovepass(self):
         e = self.a.initGroup('group28_1')
         e[libuser.SHADOWPASSWORD] = '07Js7N.eEhbgs'
