@@ -87,9 +87,9 @@ class Tests(unittest.TestCase):
         e[libuser.COMMONNAME] = 'Common Name'
         e[libuser.GIVENNAME] = 'Given'
         e[libuser.SN] = 'Surname'
-        e[libuser.ROOMNUMBER] = 404
-        e[libuser.TELEPHONENUMBER] = 1234
-        e[libuser.HOMEPHONE] = 4321
+        e[libuser.ROOMNUMBER] = '404'
+        e[libuser.TELEPHONENUMBER] = '1234'
+        e[libuser.HOMEPHONE] = '4321'
         e[libuser.EMAIL] = 'user6_2@example.com'
         self.a.addUser(e, False, False)
         del e
@@ -113,9 +113,9 @@ class Tests(unittest.TestCase):
         self.assertEqual(e[libuser.COMMONNAME], ['Common Name'])
         self.assertEqual(e[libuser.GIVENNAME], ['Given'])
         self.assertEqual(e[libuser.SN], ['Surname'])
-        self.assertEqual(e[libuser.ROOMNUMBER], [404])
-        self.assertEqual(e[libuser.TELEPHONENUMBER], [1234])
-        self.assertEqual(e[libuser.HOMEPHONE], [4321])
+        self.assertEqual(e[libuser.ROOMNUMBER], ['404'])
+        self.assertEqual(e[libuser.TELEPHONENUMBER], ['1234'])
+        self.assertEqual(e[libuser.HOMEPHONE], ['4321'])
         # Not stored by our LDAP module
         # self.assertEqual(e[libuser.EMAIL], ['user6_2@example.com'])
 
@@ -226,6 +226,17 @@ class Tests(unittest.TestCase):
         self.assertEqual(e[libuser.UIDNUMBER], [LARGE_ID + 730])
         self.assertEqual(e[libuser.GIDNUMBER], [LARGE_ID + 731])
 
+    def testUserMod4(self):
+        # No modification at all
+        e = self.a.initUser('user7_4')
+        self.a.addUser(e, False, False)
+        del e
+        e = self.a.lookupUserByName('user7_4')
+        self.a.modifyUser(e, False)
+        del e
+        e = self.a.lookupUserByName('user7_4')
+        self.assert_(e)
+
     def testUserDel(self):
         e = self.a.initUser('user8_1')
         self.a.addUser(e, False, False)
@@ -340,13 +351,19 @@ class Tests(unittest.TestCase):
     def testUserSetpass1(self):
         e = self.a.initUser('user12_1')
         e[libuser.USERPASSWORD] = '{CRYPT}02oawyZdjhhpg'
+        e[libuser.SHADOWLASTCHANGE] = 100
         self.a.addUser(e, False, False)
         del e
         e = self.a.lookupUserByName('user12_1')
         self.assertEqual(e[libuser.USERPASSWORD], ['{CRYPT}02oawyZdjhhpg'])
+        self.assertEqual(e[libuser.SHADOWLASTCHANGE], [100])
         self.a.setpassUser(e, 'password', False)
+        del e
+        e = self.a.lookupUserByName('user12_1')
         crypted = crypt.crypt('password', e[libuser.USERPASSWORD][0][7:])
         self.assertEqual(e[libuser.USERPASSWORD], ['{CRYPT}' + crypted])
+        self.assert_(e[libuser.SHADOWLASTCHANGE][0] > 10000)
+
 
     def testUserSetpass2(self):
         e = self.a.initUser('user12_2')
@@ -379,12 +396,17 @@ class Tests(unittest.TestCase):
     def testUserRemovepass1(self):
         e = self.a.initUser('user13_1')
         e[libuser.USERPASSWORD] = '{CRYPT}03dgZm5nZvqOc'
+        e[libuser.SHADOWLASTCHANGE] = 100
         self.a.addUser(e, False, False)
         del e
         e = self.a.lookupUserByName('user13_1')
         self.assertEqual(e[libuser.USERPASSWORD], ['{CRYPT}03dgZm5nZvqOc'])
+        self.assertEqual(e[libuser.SHADOWLASTCHANGE], [100])
         self.a.removepassUser(e)
+        del e
+        e = self.a.lookupUserByName('user13_1')
         self.assertEqual(e[libuser.USERPASSWORD], ['{CRYPT}'])
+        self.assert_(e[libuser.SHADOWLASTCHANGE][0] > 10000)
 
     def testUserRemovepass2(self):
         e = self.a.initUser('user13_2')
